@@ -353,8 +353,13 @@ class Node(Base):
         data = {}
         if order in (BREADTH_FIRST, DEPTH_FIRST):
             data.update({"order": order})
-        if isinstance(stop, (int, float)) or stop is STOP_AT_END_OF_GRAPH:
+        if isinstance(stop, (int, float)):
             data.update({"max depth": stop})
+        elif stop is STOP_AT_END_OF_GRAPH:
+            data.update({'prune evaluator':{
+                            'language':'javascript',
+                            'body':'false',
+            }})
         if returnable in (BREADTH_FIRST, DEPTH_FIRST):
             data.update({"return filter": {
                             "language": "builtin",
@@ -890,7 +895,8 @@ class Extension(object):
             # the extensions is implemented in Neo4j
             returns = kwargs.pop("returns", None)
             # Another option is to inspect the results
-            if not returns and isinstance(results_list, (tuple, list)):
+            if (not returns and isinstance(results_list, (tuple, list))
+                and len(results_list) > 0):
                 returns = results_list[0].get("self", None)
             if results_list and returns:
                 if NODE in returns:
